 subroutine calcul_dfsat(int_allocate,cle,line,tab_orb,dateor_deb,dateor_fin,ncycle,nbptor,tab_dfsat) 
  !
  !***********************************************************************
  !
  ! AIM
  ! ----
  !     ! calculation of frequency correction (dfsat) for one cycle by step of 10s
  !     ! or by step of the orbit file when using sp3orbit file
  !     ! and arrangement in an array of the obtained values (dates and dfsat)
  !     ! determination of the number calculated values of dfsat
  !     ! (useful to increment the array of dfsat)
  !
  ! ARGUMENTS
  ! ---------
  !*ARG (IN) cle : if =new using of the external sp3 file 
  !*ARG (IN) int_allocate
  !*ARG (IN) tab_orb: array of the ground track determined from orbit file
  !*ARG (INOUT) line : number of end line of last calculated value of dfsat
  !*ARG (IN) dateor_deb : begin date of cycle  
  !*ARG (IN) dateor_fin : end date of cycle
  !*ARG (IN) nbptor : approximate total number of calculated values of dfsat 
  !*ARG (OUT) tab_dfsat : array of dates and corresponding calculated values of dfsat   
  !
  !
  ! MODULES
  ! -------
  ! f90_kind  
  !
  !
  ! CALLED BY 
  ! ---------
  ! Main program
  !
  !
  ! CALL
  ! ---------
  ! hf_jason_doris_freq
  ! modele_fsat_doris
  !
  !***********************************************************************
  !    
  use f90_kind 
  !.. Implicit Declarations .. 
  implicit none

  !.. Formal Arguments .
  integer(SINGLE),intent(in) :: int_allocate
  character*3,intent(in) :: cle
  integer(SINGLE),intent(inout) :: line
  real(SINGLE),intent(in) :: dateor_deb,dateor_fin
  integer(SINGLE),intent(in) :: nbptor
  integer,intent(in) :: ncycle

  real(SINGLE),intent(in),dimension(int_allocate,3) :: tab_orb

  real(SINGLE),intent(out),dimension(nbptor,3) :: tab_dfsat 

  ! 
  !.. Local Scalars ..
  logical :: l_initialiser,l_elim
  real(SINGLE) :: date,xlat,xlon,dfsatLT,date_deb_type,date_fin_type,dfjas_jdhf  
  real(SINGLE), save :: datpre

  integer :: i,itab,itab2
 
  ! ... Executable Statements ...
 
  ! begin and end dates of reference cycle
  date_deb_type = 0._S
  date_fin_type = 9.91562865751777_S 
 
  itab=0
  ! initialization in the case of the first value of dfsat array
  if (line == 1) then
    l_initialiser = .true.
    datpre = 0
  endif

  ! opening of the reference cycle file (mean ground track of TOPEX)
  if (ncycle > 260 .AND. ncycle < 262) then
    print*,'Bad period for cycle',ncycle
    print*,'Input file has to correspond either'
    print*,'- to the before drift orbit period (before cycle 259, January 26, 2009, 08H21m40s)'
    print*,'- or to the after drift period (after cycle 263, February 20, 2009, 03H51m01s)'
    print*,'You have to change Input file'
    stop
  endif 

  ! opening of the output file (jason_position.dat) for each cycle considered (latitude and longitude by 10s step)
  open (39,file = 'OUTPUT/jason_position.dat',position='append')

  if ( cle == "new" ) then 
    do i=1,nbptor
      if(l_initialiser) then
  ! calculation of the first value of dfsat array      
      call hf_jason_doris_freq(l_initialiser,tab_orb(i,1),tab_orb(i,2),tab_orb(i,3),dfjas_jdhf,l_elim)
      cycle
     endif

     call hf_jason_doris_freq(l_initialiser,tab_orb(i,1),tab_orb(i,2),tab_orb(i,3),dfjas_jdhf,l_elim)

  ! remove overlap values        
     if (l_elim) then
      itab=itab+1
      cycle
     endif

     itab2=i-itab
     tab_dfsat(itab2,1) = tab_orb(i,1)
     tab_dfsat(itab2,2) = dfjas_jdhf

  ! calculation of the frequency long term correction (dfsatLT)
     call modele_fsat_doris(tab_orb(i,1),dfsatLT)
     tab_dfsat(itab2,3) = dfsatLT

  ! writing of the position  
     write (39,51) tab_dfsat(itab2,1),tab_orb(i,2),tab_orb(i,3)
  ! incrementing of the number of calculated values 
     line = line + 1     
    enddo
 
  else

   if (ncycle < 260) then
    open (21,file = 'ANNEXE/ORBITE/topex_mean_track_TRACE1',status='OLD')
   else
    open (21,file = 'ANNEXE/ORBITE/topex_mean_track_TRACE2',status='OLD')
   endif 

  ! loop to calculate dfsat for the cycle considered (at longitude and latitude of corresponding date)
   do
  ! one uses the cycle of reference to determine the cycle considered (corresponding between the date and the latitude/longitude)
    read(21,50,end=1300)date,xlat,xlon
  ! determination of the date of the current cycle
    date = ((dateor_fin - dateor_deb)/(date_fin_type - date_deb_type))*(date - date_deb_type) + dateor_deb
    if (date == datpre) CYCLE 
    datpre = date
  ! initialization in the case of the first value of dfsat array  
    if(l_initialiser) then
  ! calculation of the first value of dfsat array      
      call hf_jason_doris_freq(l_initialiser,date,xlat,xlon,dfjas_jdhf,l_elim)
      cycle
    endif
  ! calculation of frequency correction (dfsat) for a cycle by step of 10s and arrangement in an array of the obtained values  
    call hf_jason_doris_freq(l_initialiser,date,xlat,xlon,dfjas_jdhf,l_elim)
    tab_dfsat(line,1) = date
    tab_dfsat(line,2) = dfjas_jdhf
  ! calculation of the frequency long term correction (dfsatLT)
    call modele_fsat_doris(date,dfsatLT)
    tab_dfsat(line,3) = dfsatLT
  ! writing of the position for one cycle 
    write (39,51) tab_dfsat(line,1),xlat,xlon
  ! incrementing of the number of calculated values 
    line = line + 1
   enddo

  endif

1300  continue  
  close(21)
  close(39)
  ! reading format
50  FORMAT(e22.17,2x,f10.6,2x,f10.6)
  
  ! writing format
51  FORMAT(f17.11,2f11.6)

end subroutine calcul_dfsat

