subroutine entetesp3(datemes_deb,datemes_fin,i,nbsp3,nstep,nvit,time_system)
  !***********************************************************************
  !
  ! AIM
  ! ----
  !     ! Read sp3 file header 
  !
  ! ARGUMENTS
  ! ---------
  !*ARG (IN) datemes_deb : measurement beginning date  
  !*ARG (IN) date_mes_fin : measurement ending date   
  !*ARG (IN) i : counter of sp3 files
  !*ARG (IN) nbsp3:  number of sp3 files
  !*ARG (OUT) nstep : number of line of position in sp3 file
  !*ARG (OUT) nvit : if nvit=1 velocity given in sp3 file  
  !*ARG (OUT) time_system : refrence time (TAI, UTC, ...)    
  !
  !
  ! MODULES
  ! -------
  ! f90_kind  
  !
  !
  ! CALLED BY 
  ! ---------
  ! Main program
  !
  !
  !***********************************************************************

  use f90_kind  

  implicit none

  integer(SINGLE)             , intent(out) :: nstep
  integer                     , intent(out) :: nvit
  character(len=3)            , intent(out) :: time_system 

  integer                                  :: ian,imoi,ijour,iheur,imin,nsatot,jul

  character(len=3)                       :: codec_init
  character(len=20)                      :: ligneSignature1
  character(len=60)                      :: o,co ,d1
  integer(SINGLE)                        :: id1,nweek,juld,i,nbsp3
  real(SINGLE)                           :: step,secs,sec_in_day,secweek,dateorb_deb,dateorb_fin,datemes_deb,datemes_fin
  
  character(len=3)                       :: codec_num
  character(len=2)                       :: temp1
  character(len=4)                       :: temp2

 !... External Functions ...
  external jul 
  
  ! Comment line in sp3 file
  o='/* CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC'
  nvit=0

  !
  read(20,300) codec_init,ian,imoi,ijour,iheur,imin,secs,nstep,ligneSignature1
 
  if ( codec_init == '#cV' ) nvit=1
  read(20,310) temp1,nweek,secweek,step,juld,sec_in_day
  read(20,325) temp2,nsatot,codec_num
  if ( codec_num .ne. "L08" ) then 
   print*,'It is not the satellite Jason1 considered, the sp3 code is ',codec_num,'instead of L08 for Jason1'
   stop
  endif 

  dateorb_deb = jul(ijour,imoi,ian)+((3600*iheur+imin*60+secs)/86400.0_S) 
  dateorb_fin = dateorb_deb+((nstep-1)*step)/86400._S
  if ( i == 0 .AND. datemes_deb < dateorb_deb ) then
   print 10006
   stop
  endif

  if ( i == (nbsp3-1) .AND. datemes_fin > dateorb_fin ) then
   print 10006
   stop
  endif  

  do id1=1,9
      read(20,*)
  enddo 
  read(20,330) d1
  time_system=d1(10:12)
  if ( time_system .ne. "TAI" ) then
   if ( time_system .ne. "UTC" ) then
    print*,'The time system is not in TAI or UTC',time_system
    stop
   endif
  endif
  do id1=1,9
      read(20,330) co
  enddo 
  if ( co .ne. o ) then
   print*,'There is a problem in the head of the sp3 file'
   stop
  endif  


300 format(a3,i4,4(1x,i2),1x,f11.8,1x,i7,1x,a20)
310 format(a2,1x,i4,1x,f15.8,1x,f14.8,1x,i5,1x,f15.13)

320 format(a9,17(a3))
325 format(a4,i2,3x,a3)

330 format(a60)

10006 format(/'*************************************************'/ &
  'The sp3 files do not cover the measurement period' / &
  'Please change the sp3 files in input' / &
  '*************************************************')   

end subroutine entetesp3
