module f90_kind
  ! PORTABLE KIND DEFINITION MODULES FOR FORTRAN 90
  ! Author : Laurent HILL, SIMULOG Sophia Antipolis
  ! Laurent.Hill@sophia.inria.fr
  ! WARNING : AVAILABILITY AND CHARACTERISTICS OF FLOATING POINT
  ! FOMATS ARE INHERENTLY MACHINE DEPENDENT.
  ! SOME IMPLEMENTATION MAY NOT PROVIDE SOME OF THE SPECIFIED
  ! REPRESENTATION, OR SOME REPRESENTATIONS MAY NOT HAVE THE EXPECTED 
  ! CHARACTERISTICS. (i.e. integer(INT8) is allowed to be 32 bit long !)

  ! REAL kinds : a conservative number of digits is used
  !              to get the right size across various machine float formats
  integer, parameter :: REAL32  = selected_real_kind(6)
  integer, parameter :: REAL64  = selected_real_kind(12)
  integer, parameter :: REAL128 = selected_real_kind(24)

  ! INTEGER kinds
  integer, parameter :: INT8    = selected_int_kind(2)
  integer, parameter :: INT16   = selected_int_kind(4)
  integer, parameter :: INT32   = selected_int_kind(18)
 
  ! REAL kinds 
  integer, parameter :: SINGLE = REAL64
  integer, parameter :: DOUBLE = REAL128
  
  ! ANO2.11
  integer, parameter :: S = SINGLE
  integer, parameter :: D = DOUBLE
   
end module f90_kind
