subroutine hf_jason_doris_freq(l_initialiser,date,xlat,xlon,dfjas_jdhf,l_elim)
  !
  !***********************************************************************
  !
  ! AIM
  ! ----
  !     ! Model of High-frequency fluctuations of the DORIS 2 GHz oscillator 
  !     ! on-board JASON calculation of frequency correction (dfsat) 
  !
  ! ARGUMENTS
  ! ---------
  !*ARG (INOUT) l_initialiser : to initialize at the first call
  !*ARG (IN) date : input date    
  !*ARG (IN) xlat,xlon : latitude and longitude
  !*ARG (OUT) dfjas_jdhf : calculated values of dfsat   
  !
  !
  ! MODULES
  ! -------
  ! f90_kind  
  !
  !
  ! CALLED BY 
  ! ---------
  ! calcul_dfsat
  !
  ! author  : GRGS
  ! version : 1.0
  !
  !***********************************************************************

  use f90_kind
  ! 
  !.. Implicit Declarations .. 
  implicit none
  ! 
  !.. Parameters .. 
  integer, parameter :: latmin = -90
  integer, parameter :: latmax = 89
  integer, parameter :: lonmin = 0
  integer, parameter :: lonmax = 359

  !.. Formal Arguments .. 
  logical, intent(inout) :: l_initialiser
  real(SINGLE), intent(in) :: date,xlat,xlon
  real(SINGLE), intent(out) :: dfjas_jdhf
  logical, intent(out) :: l_elim
   
  !.. Local Scalars .. 
  integer :: lat,lon,ch
  integer :: lat_sc,lon_sc,lat_u,lat_d,lon_l,lon_r
  real(SINGLE) :: a0,a1,a2,a3,a4,a5,dcdcsdt,theor_flux,dt,f_memory_effect, &
    fracd,fsin,fcos,hloc,t_relax
  real(SINGLE) :: amp_inst,ang,exp_dec,saa,amplitude,ang2
  real(SINGLE) :: mean_cumulated_dose,date19,temp           
  real(SINGLE), save :: mean_cumulated_dose_init
  real(SINGLE), save :: dlat,dlon
  real(SINGLE) :: wu,wd,wr,wl
  real(SINGLE), save :: date_initiale,previous_date,previous_xlat, &
    previous_xlon,cumulated_dose,current_dose
  real(SINGLE) :: distA,distB,wbl,wbr,wtl,wtr,xlatemp  
  ! 
  !.. Local Arrays .. 
  real(SINGLE), dimension(latmin:latmax,lonmin:lonmax), save :: tab_saa = 0.0_S
  ! 
  !.. Intrinsic Functions .. 
  intrinsic cos, exp, int, real, sin
  !
  !.. Internal function declaration
  real(SINGLE) :: a10,a11,a12,a13,a14,a15,compute_mcd
  data a10,a11,a12,a13,a14,a15/-0.15462_S,-0.042982_S,0.0014701_S, &
   -1.6776e-06_S,7.98e-10_S,-1.6378e-13_S/
  compute_mcd(a10,a11,a12,a13,a14,a15,date19) = a10+a11*date19+a12*date19**2+&
    a13*date19**3+a14*date19**4+a15*date19**5
  real(SINGLE) :: a16,a17,a18,a19,a20,compute_mcd2
  data a16,a17,a18,a19,a20/-5.0368_S,-0.52555_S,-0.00012119_S,-1.9489E-12_S,1.767E-15_S/ 
  compute_mcd2(a16,a17,a18,a19,a20,date19) = a16+a17*date19+a18*date19**2+&
    a19*date19**3+a20*date19**4 
  real(SINGLE) :: a21,a22,a23,a24,a25,compute_mcd3 
  data a21,a22,a23,a24,a25/1546.7_S,-0.90971_S,1.0264E-09_S,-2.2507E-12_S,4.6496E-16_S/  
  compute_mcd3(a21,a22,a23,a24,a25,date19) = a21+a22*date19+a23*date19**2+&
    a24*date19**3+a25*date19**4
  ! 
  !... Executable Statements ...

  ! version : 1.0

  ! determinaion of model parameters

  ! determination of parameters of USO2
  if (date <19904 .AND. date > 18998) then  
    ch = 2
    date19 = date-19000._S
    
  ! temporal evolution of the amplitude (order two polynomial)
    a0 = -0.892_S
    a1 = 0.05846_S
    a2 = -1.936E-5_S
    amplitude = a0+a1*date19+a2*date19**2

  ! temporal evolution of the relaxation time (exponential decay)  
    a0 = 0.00467_S
    a1 = 0.0088_S
    a2 = 222.39_S
    t_relax = a0 + a1*exp(-date19/a2)

  ! temporal evolution of the memory effect (exponential decay)  
    a0 = -0.16755_S
    a1 = 0.76542_S
    a2 = 873.69_S
    f_memory_effect = a0 + a1*exp(-date19/a2)

  ! additional parameter: fcos
    ang = date19 / 117.6_S * 2._S * 3.14159_S
    a0 = -0.0186191_S
    a1 = 0.0472369_S
    a2 = 0.00390004_S
    a3 = 0.0311919_S
    a4 = -0.03961_S
    fcos = (a0+a1*cos(ang)+a2*sin(ang)+a3*cos(ang*2._S)+a4*sin(ang*2._S)) * amplitude

  ! additional parameter: fsin  
    a0 = 0.0503389_S
    a1 = -0.0153753_S
    a2 = -0.0229362_S
    a3 = -0.0297466_S
    a4 = -0.0261612_S
    fsin = (a0+a1*cos(ang)+a2*sin(ang)+a3*cos(ang*2._S)+a4*sin(ang*2._S)) * amplitude
! end of the determination of parameters of USO2
  endif
  
  ! determination of parameters of USO1
  if (date >= 19907) then 
    ch = 1
    date19 = date-19900._S
  
  ! temporal evolution of the amplitude 
    amplitude = -8.4345_S-0.00389_S*date19
    if (date >= 21600) amplitude = -14.6_S 
    
  ! temporal evolution of the relaxation time (constant)  
    t_relax = 0.028_S

  ! temporal evolution of the memory effect (constant)  
    f_memory_effect = 0.7_S
  endif
  ! end of the determination of parameters of USO1

  ! period without measurements
  if (date > 19903 .AND. date < 19907) then
    print*,'Bad period'
    print*,'Input file has to correspond either'
    print*,'- to the chain 2 period (on December 7, 2001, until June 25, 2004)'
    print*,'- or to the chain 1 period (after July 3, 2004)'
    print*,'You have to change Input file'
    stop
  endif

  ! initialization phase  
  
  l_elim=.false. 
  
  if (l_initialiser) then
    l_initialiser = .false.
    date_initiale = date
    previous_date = date
    previous_xlat = xlat
    previous_xlon = xlon
    current_dose = 0._S
    cumulated_dose = 0._S
    dfjas_jdhf = 0._S
    
    if (ch == 2) mean_cumulated_dose_init = compute_mcd(a10,a11,a12,a13,a14,a15,date19)
    if (ch == 1) then
      mean_cumulated_dose_init = compute_mcd2(a16,a17,a18,a19,a20,date19)
      if (date >= 21600)  mean_cumulated_dose_init = compute_mcd3(a21,a22,a23,a24,a25,date19)
    endif
 
  ! opening and reading of the SAA grid for one time and arrangement in an array
    if (ch == 2) open (49,file = 'ANNEXE/TABSAA/SAA_grid_CH2',status='OLD')
    if (ch == 1) open (49,file = 'ANNEXE/TABSAA/SAA_grid_CH1',status='OLD')
    read (49,*) ((tab_saa(lat,lon), lon = lonmin,lonmax), lat=latmax,latmin,-1)
    close (49)
    dlat = 1._S
    dlon = 1._S
  end if
  ! end of initialization phase
  
  ! time variation
  dt = date - previous_date

  if ( dt <= 0.0_S ) then
   l_elim=.true.
   go to 100
  endif

  ! calculation of the geographic dependency of the SAA amplitude by
  ! bilinear interpolation.
  ! lat_sc, lon_sc : lat and lon of the center of the 1 degree cell containing
  ! xlat and xlon
  lat_sc=nint(xlat)
  lon_sc=nint(xlon)
  wu=0.5_S+(xlat-real(lat_sc))/dlat
  wd=1._S-wu
  wr=0.5_S+(xlon-real(lon_sc))/dlon
  wl=1._S-wr
  lat_u=lat_sc
  lat_d=lat_sc-1
  lon_l=lon_sc-1
  lon_r=lon_sc
  if (lon_l == -1) lon_l=359
  if (lon_r == 360) lon_r=0
  saa = wu*wl*tab_saa(lat_u,lon_l) + wu*wr*tab_saa(lat_u,lon_r) + &
        wd*wl*tab_saa(lat_d,lon_l) + wd*wr*tab_saa(lat_d,lon_r)

  ! calculation of the modelled value of the SAA dose flux
  fracd = date - real(int(date))
  hloc = fracd
  if (ch == 2) amp_inst = amplitude + fcos*cosd(360._S*hloc) + fsin*sind(360._S*hloc)
  if (ch == 1) amp_inst = amplitude
  
  theor_flux = amp_inst * saa
  ! relaxation: exponential decay of modelled amount 
  exp_dec = -current_dose/t_relax
  ! derivative of the current amount
  dcdcsdt = theor_flux + exp_dec
  ! flux integration
  current_dose = current_dose + dcdcsdt*dt
  ! memory effect
  cumulated_dose = cumulated_dose + theor_flux*f_memory_effect*dt
  
  if (ch == 2) mean_cumulated_dose = compute_mcd(a10,a11,a12,a13,a14,a15,date19) - &
                                     mean_cumulated_dose_init
  if (ch == 1) then
   mean_cumulated_dose = compute_mcd2(a16,a17,a18,a19,a20,date19)- mean_cumulated_dose_init
   if (date >= 21600) mean_cumulated_dose = compute_mcd3(a21,a22,a23,a24,a25,date19)- mean_cumulated_dose_init
  endif

! model of frequency correction
  dfjas_jdhf = current_dose*(1._S-f_memory_effect) + cumulated_dose -  mean_cumulated_dose

! Re-initialization
  previous_date = date
  previous_xlat = xlat
  previous_xlon = xlon

100 continue

end subroutine hf_jason_doris_freq
