subroutine interpol_datemes(nformat,nbmes,tab_dfsat,nbptor,line)
  !
  !***********************************************************************
  !
  ! AIM
  ! ----
  !     ! interpolation at the measurement date with table of frequency correction (dfsat) given by step of 10s
  !
  ! ARGUMENTS
  ! ---------
  !*ARG (IN) nformat : indicate the format of the measurement file  
  !*ARG (IN) nbmes : number of measurements 
  !*ARG (IN) tab_dfsat : array of dates and corresponding calculated values of dfsat 
  !*ARG (IN) nbptor : approximate total number of calculated values of dfsat    
  !*ARG (IN) line : number of calculated values of dfsat
  !
  ! MODULES
  ! -------
  ! f90_kind  
  !
  !
  ! CALLED BY 
  ! ---------
  ! Main program
  !
  !
  ! CALL
  ! ---------
  ! jul
  ! modele_fsat_doris
  !
  !***********************************************************************
  !      
  use f90_kind
  !.. Implicit Declarations .. 
  implicit none
  !.. Formal Arguments .
  integer(SINGLE),intent(in) :: nformat,nbmes,line,nbptor
  real(SINGLE),intent(in),dimension(nbptor,3) :: tab_dfsat  
  ! 
  !.. Local Scalars ..
  integer :: jul,i,i2,jour,ian,isec,isecf,an,i1,icount
  integer(SINGLE) :: iono,itrop,jpoids,itc,ixmes,ip,it,ih,icor_iono,icor_itrop,mascor,dfsat_int
  real(SINGLE) :: sec,date,dt,poids_av,poids_ap,dfsat,dfsatLT
  character(LEN=90) :: ligne

  character(LEN=45) :: ligne1
  character(LEN=40) :: ligne2
  

  ! 
  ! ... Executable Statements ...

  ! initialization phase
  i1=1
  ! opening of the output file (jason_df.orbit.dat) and writing the frequency
  ! correction : date in TAI, high frequency (dfsat) and long term (dfsatLT) 
  open (34,file = 'OUTPUT/jason_df.orbit.dat')
  do i=1,line
    if ( tab_dfsat(i,1) .ne. 0.0_S ) write (34,10023) tab_dfsat(i,:)
  enddo
  close(34)
  
  ! opening of the output file (jason_df.measurement.dat)   
  open (36,file = 'OUTPUT/jason_df.measu.dat')

  open (37,file = 'OUTPUT/jason_df.measu2.dat')
  
  ! opening of the measurement file   
  open (17,file='ANNEXE/MESURE/Input',status='OLD')  
  ! loop to read all measurements    
  do i2=1,nbmes
  ! reading according to format file  
    if (nformat == 1_S) then
      read (17,10030) ligne1,ixmes, ligne2
      read (ligne1,10024) ian,jour,isec,isecf,icount

    
  ! the calculation is centered at the middle of the count interval

      isecf = isecf + icount/20
    else
      read (17,*)ian,jour,isec,isecf
    endif
  ! calendar date conversion into julien day CNES (real) date
    if (ian < 1900) then
      if (ian < 50) then
        an = ian+2000
      else
        an = ian+1900
      end if
    else
      an = ian
    endif
    date = jour + jul(1,1,an) - 1
    sec = real(isec,SINGLE) + 1.e-6_S*real(isecf,SINGLE)
    date = real(date,SINGLE) + sec/86400._S
 
  ! to seek dates which frame the date of measurement
    if (date > tab_dfsat(line,1)) then
      print 10025,tab_dfsat(line,1)
      return
    endif
    if (date < tab_dfsat(i1,1)) then
      i1 = 1
    endif
  ! loop to find the limit dates  
    do i=i1,line 
      if (date >= tab_dfsat(i,1) .AND. date <= tab_dfsat(i+1,1)) then
        i1 = i
        exit
      endif
    enddo
  ! linear interpolation at the measurement date
    dt = tab_dfsat(i+1,1) - tab_dfsat(i,1)
  ! calculation of the relative weight 
    poids_av = (tab_dfsat(i+1,1) - date) / dt
    poids_ap = (date - tab_dfsat(i,1)) / dt
  ! linear interpolation to obtain dfsat  
    dfsat = poids_av * tab_dfsat(i,2) + poids_ap * tab_dfsat(i+1,2)
  ! calculation of long term at the date of measurement  
    call modele_fsat_doris(date,dfsatLT)

  ! writing of results in output files according to format files
  ! jason_df.measurement.dat file contains : measurement date (jjCNES real),dfsat,dfsat long term
  ! Dfsat_MESURE.res file contains : measurement date (measurement format),dfsat,dfsat long term    
    if (nformat == 1_S) then
      dfsat_int= nint(-dfsat*1.e6_S*1.4723e-1_S)      
      dfsat_int=dfsat_int+ixmes
      write(37,10030) ligne1,dfsat_int,ligne2
      write(36,10026) ligne1,ixmes,ligne2,date,dfsat,dfsatLT
    else
      write(36,10029) ian,jour,isec,isecf,date,dfsat,dfsatLT
    endif
    
  enddo

  close (17)
  close (36)

  close (37)
  
  ! ... Format Declarations ...
  ! reading format
10024 format (16x,i2,i3,i5,i6,3x,i10)
  ! writing format
10023 format (f17.11,3x,f16.10,3x,f12.6)
10026 format (a45,i11,a40,1x,f17.11,2f12.6)

10030 format (a45,i11,a40)  
  
10029 format (i4.2,1x,i3.3,1x,i5,1x,i6,1x,f17.11,2f12.6)
10025 format ('Interpolation stops at date ',f18.12)
end subroutine interpol_datemes

