   ! EXTERNAL SUBROUTINES 
include 'f90_kind.f90'
include 'cortai.f90'
include 'jul.f90'
include 'hf_jason_doris_freq.f90'
include 'modele_fsat_doris.f90'
include 'interpol_datemes.f90'
include 'date_cycle.f90'
include 'lecture_doris_file_init.f90'
include 'calcul_dfsat.f90'

include 'conv_orbsp3_orbgeo.f90'
include 'entetesp3.f90'
include 'xyzflh.f90'
include 'angle.f90'
include 'egalite.f90'
include 'common_cons.f90'

!***********************************************************************
  !
  ! HISTORIC : November 2004
  ! ----------
  !
  ! AIM
  ! ----
  !*
  !*  Main program of the calculation of correction of the USO jason1 frequency
  !*  
  !*            
  !***********************************************************************


program modele
  use f90_kind
  ! Portable kind definition module for FORTRAN 90

  !... Implicit Declarations ... 
  implicit none
 
  ! Local scalars  measurement file
  integer(SINGLE) :: nbmes
  real(SINGLE) :: datemes_deb,datemes_fin
  integer :: ncycle
  
  ! Local scalars orbital file
  integer(SINGLE) :: nbptor
  real(SINGLE) :: dateor_deb,dateor_fin,dateor_temp
  ! Local Array
  real(SINGLE),dimension(:,:),allocatable :: tab_dfsat  

  ! Local scalars
  character*1 :: cformat
  real(SINGLE) :: duree_type
  integer(SINGLE) :: nduree,line,nformat,il

  integer(SINGLE) :: i,nstep,nstep_temp,int_allocate,nbsp3
  integer         ::  nvit
  character(len=3) :: time_system
  real(SINGLE),dimension(:,:),allocatable :: tab_orb

  character*3 :: cle



  !... External Functions ...
  external lecture_doris_file_init,date_cycle,calcul_dfsat,interpol_datemes 
    
  !... Intrinsic Functions ..
  intrinsic int

  !... Executable Statements ...

  ! cleaning file OUTPUT/jason_position.dat
  open (39,file = 'OUTPUT/jason_position.dat',status='replace')
  close (39)

  ncycle=0
  int_allocate=0
  cle="old"
  i=0

  ! choice of the measurement file format 
  print 10000
100 continue
  read(*,'(a1)') cformat
  if (cformat .ne. '1' .AND. cformat .ne. '2' .AND. cformat .ne. '3'.AND. cformat .ne. '4') then
    print *,'Wrong answer, try again !'
    go to 100
  endif

  read(cformat,'(i1)') nformat
  if ( nformat == 3 .or. nformat == 4 ) then
    print 10005
    read(*,'(i2)') nbsp3
    if ( nformat == 3 ) nformat=1
    if ( nformat == 4 ) nformat=2
    cle="new"
  endif 

  ! to seek the begin and end dates and the number of measurements starting from the file of the measurements
  call lecture_doris_file_init(nformat,datemes_deb,datemes_fin,nbmes)
  ! if the begin date of measurement exceeds the end date of the data
  
  if (datemes_fin > 22707._S .AND. cle == "old") then
   print 10006 
   stop
  endif

  if (datemes_deb < 18998._S) then
    print 10003,datemes_deb
  endif
  if (datemes_fin > 19904._S) then
    print 10004,datemes_fin
  endif

  if ( cle == "new") then

   open (20,file = 'ANNEXE/ORBITE/orbit_sp3',status='OLD') 
   call entetesp3(datemes_deb,datemes_fin,i,nbsp3,nstep,nvit,time_system)
   int_allocate=(nbsp3+1)*nstep 
   allocate(tab_orb(int_allocate,3))
   call conv_orbsp3_orbgeo(int_allocate,nstep,nvit,time_system,tab_orb)
   nstep_temp=nstep
   do i=1,(nbsp3-1) 
    call entetesp3(datemes_deb,datemes_fin,i,nbsp3,nstep,nvit,time_system) 
    call conv_orbsp3_orbgeo(int_allocate,nstep,nvit,time_system,tab_orb)
    nstep_temp=nstep_temp+nstep
   enddo 
   nstep=nstep_temp
   line = 1
   allocate(tab_dfsat(nstep,3))
   call calcul_dfsat(int_allocate,cle,line,tab_orb,tab_orb(1,1),tab_orb(nstep,1),ncycle,nstep,tab_dfsat) 
   call interpol_datemes(nformat,nbmes,tab_dfsat,nstep,line) 
   deallocate(tab_dfsat)
   deallocate(tab_orb)
  
   close (20) 
  else

   ! to seek the begin and end dates of jason cycle starting from the begin date of the measurements
   call date_cycle (datemes_deb,datemes_fin,dateor_deb,dateor_fin,ncycle)

   !to seek number of cycles to be considered : nduree

   duree_type = 9.91562865751777_S
   nduree = 0_S
   dateor_temp = dateor_deb
   do while ((datemes_fin - dateor_temp) >= 0_S) 
    nduree = nduree + 1
    dateor_temp = dateor_temp + duree_type
   enddo

  ! the orbit ground track of a cycle is given by 10 second step, which gives roughly 88310 values (date, latitude, longitude)
  ! allowance of memory for the array of dfsat values to calculate
   nbptor = nduree * 88310_S
   allocate(tab_dfsat(nbptor,3))

  ! initialization
   line = 1
      
  ! calculation of frequency correction (dfsat) for the cycle in progress
  ! determination of the number of calculated values of dfsat
   call calcul_dfsat(int_allocate,cle,line,tab_orb,dateor_deb,dateor_fin,ncycle,nbptor,tab_dfsat)
  ! the begin date of measurements becomes the end date of the cycle so as to seek the following cycle
   datemes_deb = dateor_fin

  ! as long as the end date of measurement is higher than the end date of cycle, a new cycle is considered
  ! incrementing of the number of calculated values of dfsat
   do while (datemes_fin > dateor_fin)
    call date_cycle (datemes_deb,datemes_fin,dateor_deb,dateor_fin,ncycle)
    if (dateor_deb .eq. dateor_fin) exit
    call calcul_dfsat(int_allocate,cle,line,tab_orb,dateor_deb,dateor_fin,ncycle,nbptor,tab_dfsat)
    datemes_deb = dateor_fin
   enddo
   line = line - 1

  ! interpolation of the dfsat at the date of measurement starting from the table of dfsat obtained previously
   write (*,10002)
   call interpol_datemes(nformat,nbmes,tab_dfsat,nbptor,line) 
   deallocate(tab_dfsat)

  endif

 print 10001

10000 format(/'Date equivalence: CNES ', &
  'Julian day 19000.0 <==> calendar date January 8, 2002 at 0 h'// &
  'Measurement File Name: ./ANNEXE/MESURE/Input'/ &
  'File type ?'/ &
  '1 <==> CDDIS (DORIS 2.2) before March 3, 2012 (before geodetic orbit)'/ &
  '2 <==> DATES in TAI before March 3, 2012: year, day-of-year, seconds-from-midnight, microseconds'/ &
  '3 <==> CDDIS (DORIS 2.2) and use sp3 orbit file in input'/ &
  '4 <==> DATES in TAI (year, day-of-year, seconds-from-midnight, microseconds) and use sp3 orbit file in input')
10001 format(/'End of Calculation'//'Output Files (all dates in TAI):'/ &
  '--------------------------------'/ &
  './OUTPUT/jason_position.dat : date/lat/lon of reference orbit'/ &
  './OUTPUT/jason_df.orbit.dat : date/dfsat_ST/dfsat_LT along reference orbit'/ &
  './OUTPUT/jason_df.measu.dat : date/dfsat_ST/dfsat_LT at the ', &
    'measurement points of file ./ANNEXE/MESURE/Input'/&
  'AND IF CDDIS FILE TYPE:'/&
  './OUTPUT/jason_df.measu2.dat : CDDIS FILE corrected by short-term frequency')
10002 format(/'Interpolation at the ', &
    'measurement points of file ./ANNEXE/MESURE/Input')
10003 format('First date of the measurements (',f18.12,') outside the ', &
    'operation of DORIS_JASON.instr_2')
10004 format('Date of the measurements (',f18.12,') for the ', &
    ' DORIS_JASON.instr_1')
10005 format('How many sp3 files in ANNEXE/ORBITE/orbit_sp3') 
10006 format('You have to choose 3 or 4 for file type and give a sp3 input file because ' &
    'the measurement end date is after March 3, 2012')   
end program modele
