subroutine modele_fsat_doris(date,dfsat)
  !
  !***********************************************************************
  !
  ! AIM
  ! ----
  !     ! calculation of JASON long term frequency correction (dfsat)
  ! 
  !
  ! ARGUMENTS
  ! ---------
  !*ARG (IN) date : input date    
  !*ARG (OUT) dfsat : calculated values of long term dfsat
  !
  !
  ! MODULES
  ! -------
  ! f90_kind  
  !
  !
  ! CALLED BY 
  ! ---------
  ! calcul_dfsat
  ! 
  !
  !***********************************************************************

  use f90_kind
  ! 
  !.. Implicit Declarations .. 
  implicit none
  ! 
  !.. Formal Arguments ..
  real(SINGLE), intent(in) :: date
  real(SINGLE), intent(out) :: dfsat
  ! 
  !.. Local Scalars .. 
  real(SINGLE) :: zd2,a0,a1,a2,a3,a4 
  ! 
  !.. Intrinsic Functions .. 
  intrinsic exp
  ! 
  ! ... Executable Statements ...

  ! temporal evolution of long term correction frequency
 
  ! time unit

  if (date < 19902.4_S) then
    zd2 = date - 18970._S
    a0 = 6.2166223526_S
    a1 = -0.2302295267582_S
    a2 = 5.34922182851e-05_S
    a3 = 35.07437515253_S
    a4 = 9.946882247925_S     
    dfsat = a0 + a1 * zd2**1 + a2 * zd2**2 - exp( -(zd2 - a3) / a4)
  endif
  if (date > 19906.2_S .AND. date < 20058._S) then
    zd2 = date - 19900._S
    a0 = -139.87158_S - 0.3325_S + 0.6731_S !+ 0.03352_S!(=+0.3406)
    a1 = -0.01912_S
    a2 =  -2.2E-04_S
    a3 =  27.38869_S
    a4 =  6.79332_S
    if (zd2 > 0._S) dfsat = a0 &
      + a1 * zd2**1 &
      + a2 * zd2**2 &
      - exp( -(zd2 - a3) / a4)
  else
    zd2 = date - 20000._S
    a0 = -143.38408_S + 0.6731_S/2!
    a1 = -0.09056_S
    a2 =  2.95073E-05_S
    a3 =  1.27846E-09_S
    a4 =  8.98498E-11_S
    dfsat = a0 &
      + a1 * zd2**1 &
      + a2 * zd2**2 &
      + a3 * zd2**3 &
      + a4 * zd2**4
  endif

  ! temporal evolution of long term correction frequency
 
end subroutine modele_fsat_doris

