subroutine xyzflh(x,y,z,fit,xlt,ht)
  !
  !***********************************************************************
  ! AIM
  ! ----
  !   conversion of x, y, z coordinates in fi, lambda, h.
  !   in  : ae - equatorial radius
  !         fff - flattening
  !         x, y, z - cartesian coordinates
  !   out : fit, xlt, ht - ellipsoidal coordinates in radians
  !
  ! ARGUMENTS
  ! ---------
  !*ARG (IN) x    E cartesian coordinate
  !*ARG (IN) y    E cartesian coordinate
  !*ARG (IN) z    E cartesian coordinate
  !*ARG (OUT)  fit  S latitude (rad)
  !*ARG (OUT)  xlt  S longitude (rad)
  !*ARG (OUT)  ht   S hauteur (m)
  !
  !
  ! MODULES
  ! -------
  ! f90_kind  
  ! common_cons
  !
  ! CALLED BY 
  ! ---------
  ! conv_orbsp3_orbgeo
  !
  !
  ! CALL
  ! -------
  ! angle
  ! egalite
  ! 
  !***********************************************************************
  !
  use f90_kind
  use common_cons
  ! 
  !.. Implicit Declarations .. 
  implicit none
  ! 
  !.. Parameters .. 
  real(SINGLE), parameter :: eps_fi = 1.e-10_S
  real(SINGLE), parameter :: eps_h = 1.e-8_S

  integer, parameter :: nit = 30
  ! 
  !.. Formal Arguments .. 
  real(SINGLE), intent(in) :: x
  real(SINGLE), intent(in) :: y
  real(SINGLE), intent(in) :: z
  real(SINGLE), intent(out) :: fit
  real(SINGLE), intent(out) :: xlt
  real(SINGLE), intent(out) :: ht
  ! 
  !.. Local Scalars .. 
  integer :: kler,n
  real(SINGLE) :: a2,a2mb2,ab,alim,asb,b,b2,bsa,c,cfi,cfi2,fi,fi0,gfi0,h,h0, &
                  pis2,prod,r,ro,ro2,rp,sbc,sfi,sfi2,xl,z2,ae,fff,epsi,ray,flat,angle
  logical      :: egalite
  !... External Functions ...
  external angle
  external egalite
  ! 
  !.. Intrinsic Functions .. 
  intrinsic abs, atan2, sin, sqrt
  ! 
  ! ... Executable Statements ...
  ! 
  !   initialisations
  !  ae   E equatorial radius
  !  fff  E flattening
  ray=6378136.46_S
  flat=1._S/0.29825765000000E+03_S

  ae = ray 
  pis2 = pi / 2._S
  bsa = (1._S-flat)
  asb = 1._S / bsa
  b = ae * bsa
  a2 = ae * ae
  b2 = b * b
  ab = flat / b
  a2mb2 = a2 - b2
  ro2 = x*x + y*y
  alim = a2 * eps_h * eps_h
  !   cas ou x et y sont quasi nuls
  if (ro2 < alim) then
    xlt = 0._S
    if (abs(z) < eps_h) then
      stop 'error in xyzflh  -  x,y,z are all together equal to zero'
    elseif (z < 0._S) then
      ht = -b - z
      fit = -pis2
    else
      ht = z - b
      fit = pis2
    end if
  else
    !   cas general
    ro = sqrt(ro2)
    xl = angle(x,y,kler)
    z2 = z * z
    h0 = sqrt(ro2+z2) * (1._S-1._S/sqrt(ro2/a2+z2/b2))
    gfi0 = atan2(asb*z,bsa*ro)
    fi0 = gfi0 - ab*sin(2._S*gfi0)*h0
    n = 1
    do
      sfi = sin(fi0)
      sfi2 = sfi * sfi
      cfi2 = 1._S - sfi2
      cfi = sqrt(cfi2)
      prod = a2mb2 * h0
      r = a2*cfi2 + b2*sfi2
      c = (r*ro+prod*cfi*sfi2) / a2
      sbc = (r*z-prod*sfi*cfi2) / b2
      rp = sqrt(c*c+sbc*sbc)
      fi = atan2(sbc,c)
      h = rp - sqrt(r)
      if (abs(fi-fi0)<=eps_fi*abs(fi0) .and. abs(h-h0)<=eps_h*abs(h0)) then
        exit
      elseif (n > nit) then
        print*,"maximum number of iterations reached",nit
        print*, x,y,z
        print*, fi,fi0,h,h0
        exit
      else
        fi0 = fi
        h0 = h
        n = n + 1
      end if
    end do
    fit = fi
    xlt = xl
    ht = h
  end if
end subroutine xyzflh
